<?php
return
array (
  0 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 53,
        1 => 0,
      ),
      1 => 
      array (
        0 => -2,
        1 => 32,
      ),
      2 => 
      array (
        0 => 55,
        1 => 132,
      ),
      3 => 
      array (
        0 => 111,
        1 => 100,
      ),
    ),
    'color' => 16777215,
    'filled' => true,
  ),
  1 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 58,
        1 => 10,
      ),
      1 => 
      array (
        0 => 10,
        1 => 37,
      ),
      2 => 
      array (
        0 => 10,
        1 => 37,
      ),
      3 => 
      array (
        0 => 58,
        1 => 10,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  2 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 59,
        1 => 11,
      ),
      1 => 
      array (
        0 => 11,
        1 => 39,
      ),
      2 => 
      array (
        0 => 11,
        1 => 39,
      ),
      3 => 
      array (
        0 => 59,
        1 => 11,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  3 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 61,
        1 => 15,
      ),
      1 => 
      array (
        0 => 18,
        1 => 40,
      ),
      2 => 
      array (
        0 => 18,
        1 => 40,
      ),
      3 => 
      array (
        0 => 61,
        1 => 15,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  4 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 61,
        1 => 16,
      ),
      1 => 
      array (
        0 => 18,
        1 => 41,
      ),
      2 => 
      array (
        0 => 18,
        1 => 41,
      ),
      3 => 
      array (
        0 => 61,
        1 => 16,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  5 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 62,
        1 => 17,
      ),
      1 => 
      array (
        0 => 19,
        1 => 42,
      ),
      2 => 
      array (
        0 => 19,
        1 => 42,
      ),
      3 => 
      array (
        0 => 62,
        1 => 17,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  6 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 64,
        1 => 21,
      ),
      1 => 
      array (
        0 => 21,
        1 => 46,
      ),
      2 => 
      array (
        0 => 21,
        1 => 46,
      ),
      3 => 
      array (
        0 => 64,
        1 => 21,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  7 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 65,
        1 => 22,
      ),
      1 => 
      array (
        0 => 22,
        1 => 47,
      ),
      2 => 
      array (
        0 => 22,
        1 => 47,
      ),
      3 => 
      array (
        0 => 65,
        1 => 22,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  8 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 66,
        1 => 23,
      ),
      1 => 
      array (
        0 => 23,
        1 => 48,
      ),
      2 => 
      array (
        0 => 23,
        1 => 48,
      ),
      3 => 
      array (
        0 => 66,
        1 => 23,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  9 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 67,
        1 => 26,
      ),
      1 => 
      array (
        0 => 24,
        1 => 51,
      ),
      2 => 
      array (
        0 => 24,
        1 => 51,
      ),
      3 => 
      array (
        0 => 67,
        1 => 26,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  10 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 68,
        1 => 27,
      ),
      1 => 
      array (
        0 => 25,
        1 => 52,
      ),
      2 => 
      array (
        0 => 25,
        1 => 52,
      ),
      3 => 
      array (
        0 => 68,
        1 => 27,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  11 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 69,
        1 => 29,
      ),
      1 => 
      array (
        0 => 26,
        1 => 54,
      ),
      2 => 
      array (
        0 => 26,
        1 => 54,
      ),
      3 => 
      array (
        0 => 69,
        1 => 29,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  12 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 71,
        1 => 32,
      ),
      1 => 
      array (
        0 => 28,
        1 => 57,
      ),
      2 => 
      array (
        0 => 28,
        1 => 57,
      ),
      3 => 
      array (
        0 => 71,
        1 => 32,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  13 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 72,
        1 => 35,
      ),
      1 => 
      array (
        0 => 29,
        1 => 60,
      ),
      2 => 
      array (
        0 => 29,
        1 => 60,
      ),
      3 => 
      array (
        0 => 72,
        1 => 35,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  14 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 73,
        1 => 36,
      ),
      1 => 
      array (
        0 => 30,
        1 => 61,
      ),
      2 => 
      array (
        0 => 30,
        1 => 61,
      ),
      3 => 
      array (
        0 => 73,
        1 => 36,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  15 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 74,
        1 => 37,
      ),
      1 => 
      array (
        0 => 31,
        1 => 62,
      ),
      2 => 
      array (
        0 => 31,
        1 => 62,
      ),
      3 => 
      array (
        0 => 74,
        1 => 37,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  16 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 74,
        1 => 38,
      ),
      1 => 
      array (
        0 => 31,
        1 => 63,
      ),
      2 => 
      array (
        0 => 31,
        1 => 63,
      ),
      3 => 
      array (
        0 => 74,
        1 => 38,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  17 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 75,
        1 => 39,
      ),
      1 => 
      array (
        0 => 32,
        1 => 64,
      ),
      2 => 
      array (
        0 => 32,
        1 => 64,
      ),
      3 => 
      array (
        0 => 75,
        1 => 39,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  18 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 75,
        1 => 40,
      ),
      1 => 
      array (
        0 => 32,
        1 => 65,
      ),
      2 => 
      array (
        0 => 32,
        1 => 65,
      ),
      3 => 
      array (
        0 => 75,
        1 => 40,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  19 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 76,
        1 => 42,
      ),
      1 => 
      array (
        0 => 33,
        1 => 67,
      ),
      2 => 
      array (
        0 => 33,
        1 => 67,
      ),
      3 => 
      array (
        0 => 76,
        1 => 42,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  20 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 77,
        1 => 43,
      ),
      1 => 
      array (
        0 => 34,
        1 => 68,
      ),
      2 => 
      array (
        0 => 34,
        1 => 68,
      ),
      3 => 
      array (
        0 => 77,
        1 => 43,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  21 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 79,
        1 => 47,
      ),
      1 => 
      array (
        0 => 36,
        1 => 72,
      ),
      2 => 
      array (
        0 => 36,
        1 => 72,
      ),
      3 => 
      array (
        0 => 79,
        1 => 47,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  22 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 80,
        1 => 48,
      ),
      1 => 
      array (
        0 => 37,
        1 => 73,
      ),
      2 => 
      array (
        0 => 37,
        1 => 73,
      ),
      3 => 
      array (
        0 => 80,
        1 => 48,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  23 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 81,
        1 => 49,
      ),
      1 => 
      array (
        0 => 33,
        1 => 77,
      ),
      2 => 
      array (
        0 => 33,
        1 => 77,
      ),
      3 => 
      array (
        0 => 81,
        1 => 49,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  24 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 82,
        1 => 51,
      ),
      1 => 
      array (
        0 => 34,
        1 => 79,
      ),
      2 => 
      array (
        0 => 34,
        1 => 79,
      ),
      3 => 
      array (
        0 => 82,
        1 => 51,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  25 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 83,
        1 => 53,
      ),
      1 => 
      array (
        0 => 40,
        1 => 78,
      ),
      2 => 
      array (
        0 => 40,
        1 => 78,
      ),
      3 => 
      array (
        0 => 83,
        1 => 53,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  26 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 84,
        1 => 55,
      ),
      1 => 
      array (
        0 => 41,
        1 => 80,
      ),
      2 => 
      array (
        0 => 41,
        1 => 80,
      ),
      3 => 
      array (
        0 => 84,
        1 => 55,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  27 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 85,
        1 => 56,
      ),
      1 => 
      array (
        0 => 42,
        1 => 81,
      ),
      2 => 
      array (
        0 => 42,
        1 => 81,
      ),
      3 => 
      array (
        0 => 85,
        1 => 56,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  28 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 85,
        1 => 57,
      ),
      1 => 
      array (
        0 => 42,
        1 => 82,
      ),
      2 => 
      array (
        0 => 42,
        1 => 82,
      ),
      3 => 
      array (
        0 => 85,
        1 => 57,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  29 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 86,
        1 => 59,
      ),
      1 => 
      array (
        0 => 43,
        1 => 84,
      ),
      2 => 
      array (
        0 => 43,
        1 => 84,
      ),
      3 => 
      array (
        0 => 86,
        1 => 59,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  30 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 87,
        1 => 61,
      ),
      1 => 
      array (
        0 => 44,
        1 => 86,
      ),
      2 => 
      array (
        0 => 44,
        1 => 86,
      ),
      3 => 
      array (
        0 => 87,
        1 => 61,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  31 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 90,
        1 => 65,
      ),
      1 => 
      array (
        0 => 47,
        1 => 90,
      ),
      2 => 
      array (
        0 => 47,
        1 => 90,
      ),
      3 => 
      array (
        0 => 90,
        1 => 65,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  32 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 92,
        1 => 68,
      ),
      1 => 
      array (
        0 => 49,
        1 => 93,
      ),
      2 => 
      array (
        0 => 49,
        1 => 93,
      ),
      3 => 
      array (
        0 => 92,
        1 => 68,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  33 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 93,
        1 => 71,
      ),
      1 => 
      array (
        0 => 50,
        1 => 96,
      ),
      2 => 
      array (
        0 => 50,
        1 => 96,
      ),
      3 => 
      array (
        0 => 93,
        1 => 71,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  34 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 95,
        1 => 74,
      ),
      1 => 
      array (
        0 => 52,
        1 => 99,
      ),
      2 => 
      array (
        0 => 52,
        1 => 99,
      ),
      3 => 
      array (
        0 => 95,
        1 => 74,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  35 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 97,
        1 => 77,
      ),
      1 => 
      array (
        0 => 54,
        1 => 102,
      ),
      2 => 
      array (
        0 => 54,
        1 => 102,
      ),
      3 => 
      array (
        0 => 97,
        1 => 77,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  36 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 97,
        1 => 78,
      ),
      1 => 
      array (
        0 => 54,
        1 => 103,
      ),
      2 => 
      array (
        0 => 54,
        1 => 103,
      ),
      3 => 
      array (
        0 => 97,
        1 => 78,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  37 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 98,
        1 => 79,
      ),
      1 => 
      array (
        0 => 55,
        1 => 104,
      ),
      2 => 
      array (
        0 => 55,
        1 => 104,
      ),
      3 => 
      array (
        0 => 98,
        1 => 79,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  38 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 99,
        1 => 81,
      ),
      1 => 
      array (
        0 => 56,
        1 => 106,
      ),
      2 => 
      array (
        0 => 56,
        1 => 106,
      ),
      3 => 
      array (
        0 => 99,
        1 => 81,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  39 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 100,
        1 => 83,
      ),
      1 => 
      array (
        0 => 57,
        1 => 108,
      ),
      2 => 
      array (
        0 => 57,
        1 => 108,
      ),
      3 => 
      array (
        0 => 100,
        1 => 83,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  40 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 102,
        1 => 86,
      ),
      1 => 
      array (
        0 => 59,
        1 => 111,
      ),
      2 => 
      array (
        0 => 59,
        1 => 111,
      ),
      3 => 
      array (
        0 => 102,
        1 => 86,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  41 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 102,
        1 => 87,
      ),
      1 => 
      array (
        0 => 59,
        1 => 112,
      ),
      2 => 
      array (
        0 => 59,
        1 => 112,
      ),
      3 => 
      array (
        0 => 102,
        1 => 87,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  42 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 103,
        1 => 87,
      ),
      1 => 
      array (
        0 => 60,
        1 => 112,
      ),
      2 => 
      array (
        0 => 60,
        1 => 112,
      ),
      3 => 
      array (
        0 => 103,
        1 => 87,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  43 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 104,
        1 => 89,
      ),
      1 => 
      array (
        0 => 56,
        1 => 117,
      ),
      2 => 
      array (
        0 => 56,
        1 => 117,
      ),
      3 => 
      array (
        0 => 104,
        1 => 89,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  44 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 105,
        1 => 91,
      ),
      1 => 
      array (
        0 => 57,
        1 => 118,
      ),
      2 => 
      array (
        0 => 57,
        1 => 118,
      ),
      3 => 
      array (
        0 => 105,
        1 => 91,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  45 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 53,
        1 => 0,
      ),
      1 => 
      array (
        0 => 111,
        1 => 100,
      ),
      2 => 
      array (
        0 => 55,
        1 => 132,
      ),
      3 => 
      array (
        0 => -2,
        1 => 32,
      ),
      4 => 
      array (
        0 => 53,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => false,
  ),
  46 => 
  array (
    'type' => 'text',
    'text' => '0',
    'size' => 10,
    'position' => 
    array (
      0 => 0,
      1 => 34,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  47 => 
  array (
    'type' => 'text',
    'text' => '0',
    'size' => 10,
    'position' => 
    array (
      0 => 5,
      1 => 42,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  48 => 
  array (
    'type' => 'text',
    'text' => '0',
    'size' => 10,
    'position' => 
    array (
      0 => 9,
      1 => 48,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  49 => 
  array (
    'type' => 'text',
    'text' => '1',
    'size' => 10,
    'position' => 
    array (
      0 => 12,
      1 => 54,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  50 => 
  array (
    'type' => 'text',
    'text' => '2',
    'size' => 10,
    'position' => 
    array (
      0 => 16,
      1 => 60,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  51 => 
  array (
    'type' => 'text',
    'text' => '3',
    'size' => 10,
    'position' => 
    array (
      0 => 19,
      1 => 67,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  52 => 
  array (
    'type' => 'text',
    'text' => '4',
    'size' => 10,
    'position' => 
    array (
      0 => 23,
      1 => 73,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  53 => 
  array (
    'type' => 'text',
    'text' => '5',
    'size' => 10,
    'position' => 
    array (
      0 => 28,
      1 => 82,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  54 => 
  array (
    'type' => 'text',
    'text' => '6',
    'size' => 10,
    'position' => 
    array (
      0 => 32,
      1 => 88,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  55 => 
  array (
    'type' => 'text',
    'text' => '7',
    'size' => 10,
    'position' => 
    array (
      0 => 35,
      1 => 94,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  56 => 
  array (
    'type' => 'text',
    'text' => '8',
    'size' => 10,
    'position' => 
    array (
      0 => 39,
      1 => 100,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  57 => 
  array (
    'type' => 'text',
    'text' => '9',
    'size' => 10,
    'position' => 
    array (
      0 => 42,
      1 => 106,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  58 => 
  array (
    'type' => 'text',
    'text' => '5',
    'size' => 10,
    'position' => 
    array (
      0 => 46,
      1 => 112,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
);
